% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/registration_pseudobulk.R
\name{registration_pseudobulk}
\alias{registration_pseudobulk}
\title{Spatial registration: pseudobulk}
\usage{
registration_pseudobulk(
  sce,
  var_registration,
  var_sample_id,
  covars = NULL,
  min_ncells = 10,
  pseudobulk_rds_file = NULL
)
}
\arguments{
\item{sce}{A
\link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment-class}
object or one that inherits its properties.}

\item{var_registration}{A \code{character(1)} specifying the \code{colData(sce)}
variable of interest against which will be used for computing the relevant
statistics.}

\item{var_sample_id}{A \code{character(1)} specifying the \code{colData(sce)} variable
with the sample ID.}

\item{covars}{A \code{character()} with names of sample-level covariates.}

\item{min_ncells}{An \code{integer(1)} greater than 0 specifying the minimum
number of cells (for scRNA-seq) or spots (for spatial) that are combined
when pseudo-bulking. Pseudo-bulked samples with less than \code{min_ncells} on
\code{sce_pseudo$ncells} will be dropped.}

\item{pseudobulk_rds_file}{A \code{character(1)} specifying the path for saving
an RDS file with the pseudo-bulked object. It's useful to specify this since
pseudo-bulking can take hours to run on large datasets.}
}
\value{
A pseudo-bulked \link[SingleCellExperiment:SingleCellExperiment]{SingleCellExperiment-class} object.
}
\description{
Pseudo-bulk the gene expression, filter lowly-expressed genes, and normalize.
This is the first step for spatial registration and for statistical modeling.
}
\examples{
## Ensure reproducibility of example data
set.seed(20220907)

## Generate example data
sce <- scuttle::mockSCE()

## Add some sample IDs
sce$sample_id <- sample(LETTERS[1:5], ncol(sce), replace = TRUE)

## Add a sample-level covariate: age
ages <- rnorm(5, mean = 20, sd = 4)
names(ages) <- LETTERS[1:5]
sce$age <- ages[sce$sample_id]

## Add gene-level information
rowData(sce)$ensembl <- paste0("ENSG", seq_len(nrow(sce)))
rowData(sce)$gene_name <- paste0("gene", seq_len(nrow(sce)))

## Pseudo-bulk
sce_pseudo <- registration_pseudobulk(sce, "Cell_Cycle", "sample_id", c("age"), min_ncells = NULL)
colData(sce_pseudo)
}
\seealso{
Other spatial registration and statistical modeling functions: 
\code{\link{registration_block_cor}()},
\code{\link{registration_model}()},
\code{\link{registration_stats_anova}()},
\code{\link{registration_stats_enrichment}()},
\code{\link{registration_stats_pairwise}()},
\code{\link{registration_wrapper}()}
}
\concept{spatial registration and statistical modeling functions}
